# $Id: mt-renamelabel.pl 1705 2009-11-09 05:53:53Z sekine $

package MT::Plugin::RenameLabel;

use strict;
use MT::Plugin;
@MT::Plugin::RenameLabel::ISA = qw(MT::Plugin);

use MT::Util qw( dirify );

use vars qw($PLUGIN_NAME $VERSION);
$PLUGIN_NAME = 'RenameLabel';
$VERSION = '1.41';

use MT;
my $plugin = new MT::Plugin::RenameLabel({
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => "This plugin allows you to change the labels of the fields on the entry editing screen.",
    doc_link => 'http://labs.m-logic.jp/plugins/mt-renamelabel/docs141/mt-renamelabel.html',
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.jp/',
    blog_config_template => \&template,
    settings => new MT::PluginSettings([
        ['rename_label_title'],
        ['rename_label_category'],
        ['rename_label_add_category'],
        ['rename_label_add_category_name'],
        ['rename_label_add_new_category_parent'],
        ['rename_label_make_primary'],
        ['rename_label_entry_body'],
        ['rename_label_extended_entry'],
        ['rename_label_excerpt'],
        ['rename_label_keywords'],
        ['rename_label_tags'],
        ['rename_label_status'],
        ['rename_label_publish_date'],
        ['rename_label_text_formatting'],
        ['rename_label_basename'],
        ['rename_label_accept'],
        ['rename_label_accept_comments'],
        ['rename_label_accept_trackbacks'],
        ['rename_label_outbound_trackback_urls'],
        ['rename_label_comments'],
        ['rename_label_trackbacks'],
        ['rename_label_publishing'],
        ['rename_label_assets'],
        ['rename_label_change_note'],
        ['rename_label_unpublish_date'],
        ['rename_label_entry_assets'],

        ['rename_label_page_title'],
        ['rename_label_page_folder'],
        ['rename_label_page_add_folder'],
        ['rename_label_page_change_folder'],
        ['rename_label_page_entry_body'],
        ['rename_label_page_extended_entry'],
        ['rename_label_page_excerpt'],
        ['rename_label_page_keywords'],
        ['rename_label_page_tags'],
        ['rename_label_page_status'],
        ['rename_label_page_publish_date'],
        ['rename_label_page_text_formatting'],
        ['rename_label_page_filename'],
        ['rename_label_page_accept'],
        ['rename_label_page_accept_comments'],
        ['rename_label_page_accept_trackbacks'],
        ['rename_label_page_outbound_trackback_urls'],
        ['rename_label_page_comments'],
        ['rename_label_page_trackbacks'],
        ['rename_label_page_publishing'],
        ['rename_label_page_assets'],
        ['rename_label_page_change_note'],
        ['rename_label_page_unpublish_date'],
    ]),
});

MT->add_plugin($plugin);

if (is_mt40() || is_mt41() || is_mt42()) {
    MT->add_callback('template_source.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt4_source);
} elsif (is_mt51() || is_mt52()) {
    MT->add_callback('template_source.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt51_source);
    MT->add_callback('template_param.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt51_param);
} elsif (is_mt5()) {
    MT->add_callback('template_source.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt5_source);
    MT->add_callback('template_param.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt5_param);
} elsif (is_mt6()) {
    MT->add_callback('template_source.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt6_source);
    MT->add_callback('template_param.edit_entry', 9, $plugin, \&hdlr_edit_entry_mt6_param);
} else {
    MT->add_callback('MT::App::CMS::AppTemplateSource.edit_entry', 9, $plugin, \&hdlr_edit_entry_source);
}



my @labels_mt3 = (
                "Title",
                "Category",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Basename",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                );

my @labels_mt40 = (
                "Title",
                "Category",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                );

my @labels_mt40_page = (
                "Title",
                "Folder",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Filename",
                "Accept",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                );

my @labels_mt41 = (
                "Title",
                "Category",
                "Add category",
                "Add category name",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                );

my @labels_mt41_page = (
                "Title",
                "Folder",
                "Add folder",
                "Change Folder",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Filename",
                "Accept",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                );

my @labels_mt5 = (
                "Title",
                "Category",
                "Add category",
                "Add category name",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                );

my @labels_mt5_page = (
                "Title",
                "Folder",
                "Add folder",
                "Change Folder",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Filename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                );

my @labels_mt51 = (
                "Title",
                "Category",
                "Add category",
                "Add category name",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Entry", "rename_label_entry_assets" ], # [ Label, Label's params, id(plugindata key name) ]
                );

my @labels_mt51_page = (
                "Title",
                "Folder",
                "Add folder",
                "Change Folder",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Text Formatting",
                "Filename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Page", "rename_label_page_assets" ],
                );

my @labels_mt6 = (
                "Title",
                "Category",
                "Add category",
                "Add category name",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Unpublish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Entry", "rename_label_entry_assets" ],
                );

my @labels_mt6_page = (
                "Title",
                "Folder",
                "Add folder",
                "Change Folder",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Unpublish Date",
                "Text Formatting",
                "Filename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Page", "rename_label_page_assets" ],
                );

my @labels_mt61 = (
                "Title",
                "Category",
                "Add category",
                "Add new category parent",
                "Make primary",
                "Entry Body",
                "Extended Entry",
                "Excerpt",
                "Keywords",
                "Tags",
                "Status",
                "Publish Date",
                "Unpublish Date",
                "Text Formatting",
                "Basename",
                "Accept",
                "Comments",
                "Accept Comments",
                "Accept TrackBacks",
                "Outbound TrackBack URLs",
                "Publishing",
                "Change note",
                [ "[_1] Assets", "Entry", "rename_label_entry_assets" ],
                );

sub instance { $plugin; }

sub is_mt40 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '4.0' ? 1 : 0;
}

sub is_mt41 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '4.1' ? 1 : 0;
}

sub is_mt42 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '4.2' ? 1 : 0;
}

sub is_mt5 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '5.0' ? 1 : 0;
}

sub is_mt51 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '5.1' ? 1 : 0;
}

sub is_mt52 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '5.2' ? 1 : 0;
}

sub is_mt6 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 2) eq '6.' ? 1 : 0;
}

sub is_mt60 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '6.0' ? 1 : 0;
}

sub is_mt61 {
    my $plugin = shift;
    my $version = MT->version_number;
    return substr($version, 0, 3) eq '6.1' ? 1 : 0;
}

sub template {
    my $tmpl;

    if (is_mt40()) {
      $tmpl = template_mt40();
    }
    elsif (is_mt41() || is_mt42()) {
      $tmpl = template_mt41();
    }
    elsif (is_mt51() || is_mt52()) {
      $tmpl = template_mt51();
    }
    elsif (is_mt5()) {
      $tmpl = template_mt5();
    }
    elsif (is_mt6()) {
      $tmpl = template_mt6();
    }
    else {
      $tmpl = template_mt3();
    }

    $tmpl;
}

sub template_mt3 {
    my $tmpl;

    for my $label (@labels_mt3) {
        my $id = 'rename_label_' . dirify($label);
        $tmpl .= '<div class="setting">' . "\n";
        $tmpl .= '<div class="label">' . "\n";
        $tmpl .= '<label for="' . $id . '"><MT_TRANS phrase="' . $label . '">:</label>' . "\n";
        $tmpl .= '</div>' . "\n";
        $tmpl .= '<div class="field">' . "\n";
        $tmpl .= '<p><input type="text" name="' . $id . '" id="' . $id . '" value="<TMPL_VAR NAME=' . uc ($id) . ' ESCAPE=HTML>" /></p>' . "\n";
        $tmpl .= '</div> ' . "\n";
        $tmpl .= '</div>' . "\n";
    }

    $tmpl;
}

sub make_field_mt4 {
    my ($label, $id) = @_;
    my $tmpl;

    $tmpl .= '<div id="' . $id . '-field" class="field field-left-label pkg ">' . "\n";
    $tmpl .= '<div class="field-header">' . "\n";
    $tmpl .= '<label for="' . $id . '"><MT_TRANS phrase="' . $label . '">:</label>' . "\n";
    $tmpl .= '</div>' . "\n";
    $tmpl .= '<div class="field-content ">' . "\n";
    $tmpl .= '<p><input type="text" name="' . $id . '" id="' . $id . '" value="<TMPL_VAR NAME=' . uc ($id) . ' ESCAPE=HTML>" /></p>' . "\n";
    $tmpl .= '</div> ' . "\n";
    $tmpl .= '</div>' . "\n";

    $tmpl;
}

sub make_field_mt51 {
    my ($label, $id, $params) = @_;
    if ($params) {
        $params = ' params="<__trans phrase="' . $params . '">"';
    }
    my $tmpl;
    $tmpl .= '<div id="' . $id . '-field" class="field field-left-label pkg ">' . "\n";
    $tmpl .= '<div class="field-header">' . "\n";
    $tmpl .= '<label for="' . $id . '"><__trans phrase="' . $label . '"' . $params . '>:</label>' . "\n";
    $tmpl .= '</div>' . "\n";
    $tmpl .= '<div class="field-content ">' . "\n";
    $tmpl .= '<p><input type="text" name="' . $id . '" id="' . $id . '" value="<mt:var name=' . uc ($id) . ' escape="html">" /></p>' . "\n";
    $tmpl .= '</div> ' . "\n";
    $tmpl .= '</div>' . "\n";

    $tmpl;
}

sub template_mt40 {
    my $tmpl;

    $tmpl .= '<h4><MT_TRANS phrase="Entry"></h4>' . "\n";
    for my $label (@labels_mt40) {
        my $id = 'rename_label_' . dirify($label);
        $tmpl .= make_field_mt4($label, $id);
    }

    $tmpl .= '<h4><MT_TRANS phrase="Pages"></h4>' . "\n";
    for my $label (@labels_mt40_page) {
        my $id = 'rename_label_page_' . dirify($label);
        $tmpl .= make_field_mt4($label, $id);
    }

    $tmpl;
}

sub template_mt41 {
    my $tmpl;

    $tmpl .= '<h4><MT_TRANS phrase="Entry"></h4>' . "\n";
    for my $label (@labels_mt41) {
        my $id = 'rename_label_' . dirify($label);
        $tmpl .= make_field_mt4($label, $id);
    }

    $tmpl .= '<h4><MT_TRANS phrase="Pages"></h4>' . "\n";
    for my $label (@labels_mt41_page) {
        my $id = 'rename_label_page_' . dirify($label);
        $tmpl .= make_field_mt4($label, $id);
    }

    $tmpl;
}

sub template_mt5 {
    my $tmpl;

    $tmpl .= '<h4><MT_TRANS phrase="Entry"></h4>' . "\n";
    for my $label (@labels_mt5) {
        my $id = 'rename_label_' . dirify($label);
        $tmpl .= make_field_mt4($label, $id);
    }

    $tmpl .= '<h4><MT_TRANS phrase="Pages"></h4>' . "\n";
    for my $label (@labels_mt5_page) {
        my $id = 'rename_label_page_' . dirify($label);
        $tmpl .= make_field_mt4($label, $id);
    }

    $tmpl;
}

sub template_mt51 {
    my $tmpl;

    $tmpl .= '<h4><MT_TRANS phrase="Entry"></h4>' . "\n";
    for my $label (@labels_mt51) {
        my $params = '';
        my $id;
        if (ref $label eq 'ARRAY') {
            ($label, $params, $id) = @$label;
        }
        else {
            $id = 'rename_label_' . dirify($label);
        }
        $tmpl .= make_field_mt51($label, $id, $params);
    }

    $tmpl .= '<h4><MT_TRANS phrase="Pages"></h4>' . "\n";
    for my $label (@labels_mt51_page) {
        my $params = '';
        my $id;
        if (ref $label eq 'ARRAY') {
            ($label, $params, $id) = @$label;
        }
        else {
            $id = 'rename_label_page_' . dirify($label);
        }
        $tmpl .= make_field_mt51($label, $id, $params);
    }

    $tmpl;
}

sub template_mt6 {
    my $tmpl;

    $tmpl .= '<h4><MT_TRANS phrase="Entry"></h4>' . "\n";
    my @labels = is_mt61() ? @labels_mt61 : @labels_mt6;
    for my $label (@labels) {
        my $params = '';
        my $id;
        if (ref $label eq 'ARRAY') {
            ($label, $params, $id) = @$label;
        }
        else {
            $id = 'rename_label_' . dirify($label);
        }
        $tmpl .= make_field_mt51($label, $id, $params);
    }

    $tmpl .= '<h4><MT_TRANS phrase="Pages"></h4>' . "\n";
    for my $label (@labels_mt6_page) {
        my $params = '';
        my $id;
        if (ref $label eq 'ARRAY') {
            ($label, $params, $id) = @$label;
        }
        else {
            $id = 'rename_label_page_' . dirify($label);
        }
        $tmpl .= make_field_mt51($label, $id, $params);
    }

    $tmpl;
}

sub get_data {
    my $plugin = shift;
    my ($blog_id, $field) = @_;
    my %plugin_param;

    my $field_name = 'rename_label_' . $field;

    $plugin->load_config(\%plugin_param, 'blog:'.$blog_id);
    my $key = $plugin_param{$field_name};
    unless ($key) {
        $plugin->load_config(\%plugin_param, 'system');
        $key = $plugin_param{$field_name};
    }
    $key;
}

sub hdlr_edit_entry_source {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

    $old = <<'HTML';
<label for="title"><MT_TRANS phrase="Title"></label>
<a href="#" onclick="return openManual('entries', 'entry_title')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'title');
    $new = <<"HTML";
<label for="title">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="status"><MT_TRANS phrase="Status"></label>
<a href="#" onclick="return openManual('entries', 'status');return false;" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'status');
    $new = <<"HTML";
<label for="status">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label id="publish-status"><MT_TRANS phrase="Publish On"></label>
<TMPL_ELSE>
<label id="publish-status"><MT_TRANS phrase="Entry Date"></label>
</TMPL_IF>
<a href="#" onclick="return openManual('entries', 'date')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'entry_date');
    $new = <<"HTML";
<label id="publish-status"><MT_TRANS phrase="$new_label"></label>
<TMPL_ELSE>
<label id="publish-status"><MT_TRANS phrase="$new_label"></label>
</TMPL_IF>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="category_id"><MT_TRANS phrase="Category"></label>
<a href="#" onclick="return openManual('entries', 'entry_categories')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'category');
    $new = <<"HTML";
<label for="category_id">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="text"><MT_TRANS phrase="Entry Body"></label>
<a href="#" onclick="return openManual('entries', 'body')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'entry_body');
    $new = <<"HTML";
<label for="text">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="text_more"><MT_TRANS phrase="Extended Entry"></label>
<a href="#" onclick="return openManual('entries', 'extended_entry')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'extended_entry');
    $new = <<"HTML";
<label for="text_more">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="excerpt"><MT_TRANS phrase="Excerpt"></label>
<a href="#" onclick="return openManual('entries', 'excerpt')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'excerpt');
    $new = <<"HTML";
<label for="excerpt">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="keywords"><MT_TRANS phrase="Keywords"></label>
<a href="#" onclick="return openManual('entries', 'keywords')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'keywords');
    $new = <<"HTML";
<label for="keywords">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="tags"><MT_TRANS phrase="Tags"></label>
<a href="#" onclick="return openManual('entries', 'entry_tags')" class="help">?</a> <span class="hint"><TMPL_IF NAME=AUTH_PREF_TAG_DELIM_COMMA><MT_TRANS phrase="(comma-delimited list)"><TMPL_ELSE><TMPL_IF NAME=AUTH_PREF_TAG_DELIM_SPACE><MT_TRANS phrase="(space-delimited list)"><TMPL_ELSE><MT_TRANS phrase="(delimited by '[_1]')" params="<TMPL_VAR NAME=AUTH_PREF_TAG_DELIM>"></TMPL_IF></TMPL_IF></span>
HTML
    $new_label = $plugin->get_data($blog_id, 'tags');
    $new = <<"HTML";
<label for="tags">$new_label</label>
 <span class="hint"><TMPL_IF NAME=AUTH_PREF_TAG_DELIM_COMMA><MT_TRANS phrase="(comma-delimited list)"><TMPL_ELSE><TMPL_IF NAME=AUTH_PREF_TAG_DELIM_SPACE><MT_TRANS phrase="(space-delimited list)"><TMPL_ELSE><MT_TRANS phrase="(delimited by '[_1]')" params="<TMPL_VAR NAME=AUTH_PREF_TAG_DELIM>"></TMPL_IF></TMPL_IF></span>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="status"><MT_TRANS phrase="Status"></label>
<a href="#" onclick="return openManual('entries', 'status')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'status');
    $new = <<"HTML";
<label for="status">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label id="publish-status"><MT_TRANS phrase="Entry Date"></label>
<a href="#" onclick="return openManual('entries', 'date')" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'entry_date');
    $new = <<"HTML";
<label for="publish-status">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label id="publish-status"><MT_TRANS phrase="Entry Date"></label>
HTML
    $new_label = $plugin->get_data($blog_id, 'entry_date');
    $new = <<"HTML";
<label for="publish-status">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="convert_breaks"><MT_TRANS phrase="Text Formatting"></label>
<a href="#" onclick="openTFDocs(); return false" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'text_formatting');
    $new = <<"HTML";
<label for="convert_breaks">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;


    $old = <<'HTML';
<label><MT_TRANS phrase="Basename"></label>
HTML
    $new_label = $plugin->get_data($blog_id, 'basename');
    $new = <<"HTML";
<label>$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;


    $old = <<'HTML';
<label><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="13" value="1"<TMPL_IF NAME=ALLOW_COMMENTS> checked="checked"</TMPL_IF> class="cb" /> <MT_TRANS phrase="Accept Comments"> <a href="#" onclick="return openManual('entries', 'accept_comments')" class="help">?</a></label>
HTML
    $new_label = $plugin->get_data($blog_id, 'accept_comments');
    $new = <<"HTML";
<label><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="13" value="1"<TMPL_IF NAME=ALLOW_COMMENTS> checked="checked"</TMPL_IF> class="cb" /> $new_label </label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="14" value="1"<TMPL_IF NAME="ALLOW_PINGS"> checked="checked"</TMPL_IF> class="cb" /> <MT_TRANS phrase="Accept TrackBacks"> <a href="#" onclick="return openManual('entries', 'accept_trackbacks')" class="help">?</a></label>
HTML
    $new_label = $plugin->get_data($blog_id, 'accept_trackbacks');
    $new = <<"HTML";
<label><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="14" value="1"<TMPL_IF NAME="ALLOW_PINGS"> checked="checked"</TMPL_IF> class="cb" /> $new_label </label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    $old = <<'HTML';
<label for="to_ping_urls"><MT_TRANS phrase="Outbound TrackBack URLs"></label>
<a href="#" onclick="return openManual('entries', 'urls_to_ping'); return false" class="help">?</a>
HTML
    $new_label = $plugin->get_data($blog_id, 'outbound_trackback_urls');
    $new = <<"HTML";
<label for="to_ping_urls">$new_label</label>
HTML
    $old = quotemeta($old);
    $$tmpl_ref =~ s!$old!$new! if $new_label;

    1;
}

sub transform_mt4_entry {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'title')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Title">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-title" value="title" checked="checked" disabled="disabled" class="cb" /> <__trans phrase="Title"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-title" value="title" checked="checked" disabled="disabled" class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'status')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Status">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'entry_body')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Body"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-body" value="body" checked="checked" disabled="disabled" class="cb" /> <__trans phrase="Body"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-body" value="body" checked="checked" disabled="disabled" class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'extended_entry')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Extended"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'excerpt')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Excerpt">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-excerpt" value="excerpt" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_excerpt"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Excerpt"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-excerpt" value="excerpt" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_excerpt"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'keywords')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Keywords">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-keywords" value="keywords" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_keywords"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Keywords"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-keywords" value="keywords" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_keywords"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'tags')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Tags">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" onclick="setCustomFields(); return true;" name="custom_prefs" id="custom-prefs-tags" value="tags" <mt:if name="disp_prefs_show_tags"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Tags"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" onclick="setCustomFields(); return true;" name="custom_prefs" id="custom-prefs-tags" value="tags" <mt:if name="disp_prefs_show_tags"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'text_formatting')) {
    $old = quotemeta(<<'HTML');
                    <__trans phrase="Format:">
HTML
    $new = <<"HTML";
                    <__trans phrase="$new_label:">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'outbound_trackback_urls')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Outbound TrackBack URLs">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

 ### MT4.0 specific
 if (is_mt40()) {
  if ($new_label = $plugin->get_data($blog_id, 'publish_date')) {
    $old = quotemeta(<<'HTML');
    <mt:if name="status_future">
        <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">"$>
    <mt:else>
        <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">"$>
    </mt:if>
HTML
    $new = <<"HTML";
    <mt:if name="status_future">
        <\$mt:setvar name="authored_on_label" value="$new_label"\$>
    <mt:else>
        <\$mt:setvar name="authored_on_label" value="$new_label"\$>
    </mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'category')) {
    $old = quotemeta(<<'HTML');
<mt:setvar name="container_label" value="<__trans phrase="Category">">
HTML
    $new = <<"HTML";
<mt:setvar name="container_label" value="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-category" value="category" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_category"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Category"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-category" value="category" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_category"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'basename')) {
    $old = quotemeta(<<'HTML');
    <mt:setvar name="basename_label" value="<__trans phrase="Basename">">
HTML
    $new = <<"HTML";
    <mt:setvar name="basename_label" value="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Accept">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_comments')) {
    $old = quotemeta(<<'HTML');
            <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Comments"></li>
HTML
    $new = <<"HTML";
            <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> $new_label</li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_trackbacks')) {
    $old = quotemeta(<<'HTML');
            <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <__trans phrase="TrackBacks"></li>
HTML
    $new = <<"HTML";
            <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> $new_label</li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }
 }
 ### MT4.1 & MT4.2 specific
 if (is_mt41() || is_mt42()) {
  if ($new_label = $plugin->get_data($blog_id, 'publish_date')) {
    $old = quotemeta(<<'HTML');
        <mt:if name="status_future">
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">"$>
        <mt:else>
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">"$>
        </mt:if>
HTML
    $new = <<"HTML";
        <mt:if name="status_future">
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        <mt:else>
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        </mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'category')) {
    $old = quotemeta(<<'HTML');
            label="<__trans phrase="Categories">"
HTML
    $new = <<"HTML";
            label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-category" value="category" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_category"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Category"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-category" value="category" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_category"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'basename')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="basename_label" value="<__trans phrase="Basename">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="basename_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept')) {
    $old = quotemeta(<<'HTML');
            label="<__trans phrase="Accept">"
HTML
    $new = <<"HTML";
            label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_comments')) {
    $old = quotemeta(<<'HTML');
                <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <label for="allow_comments"><__trans phrase="Comments"/></label></li>
HTML
    $new = <<"HTML";
                <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <label for="allow_comments">$new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_trackbacks')) {
    $old = quotemeta(<<'HTML');
                <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <label for="allow_pings"><__trans phrase="TrackBacks"/></label></li>
HTML
    $new = <<"HTML";
                <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <label for="allow_pings">$new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category')) {
    $old = quotemeta(<<'HTML');
            <a href="javascript:void(0)" class="add-new-category-link" id="open-category-selector1" mt:command="open-category-selector" mt:close-el="close-category-selector1" title="<__trans phrase="Add category">"><__trans phrase="edit"/></a>
HTML
    $new = <<"HTML";
            <a href="javascript:void(0)" class="add-new-category-link" id="open-category-selector1" mt:command="open-category-selector" mt:close-el="close-category-selector1" title="$new_label"><__trans phrase="edit"/></a>
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="add_container_label" value="<__trans phrase="Add category">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="add_container_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category_name')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="add_container_label_name" value="<__trans phrase="Add category name">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="add_container_label_name" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_new_category_parent')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="add_new_container_label_parent" value="<__trans phrase="Add new category parent">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="add_new_container_label_parent" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'make_primary')) {
    $old = quotemeta(<<'HTML');
                        <li class="pkg" mt:focus-hover="1" mt:id="[#= cat.id #]"><mt:if name="object_type" eq="entry"><a mt:focus-hover="1" href="javascript:void(0);" mt:command="primary" class="primary" title="[#|h trans("Make primary") #]">[#= label #]</a></mt:if><a mt:focus-hover="1" href="javascript:void(0);" mt:command="remove" class="delete" title="[#|h "Remove" #]">&nbsp;<span>[#|h trans("Remove") #]</span></a></li>
HTML
    $new = <<"HTML";
                        <li class="pkg" mt:focus-hover="1" mt:id="[#= cat.id #]"><mt:if name="object_type" eq="entry"><a mt:focus-hover="1" href="javascript:void(0);" mt:command="primary" class="primary" title="[#|h "$new_label" #]">[#= label #]</a></mt:if><a mt:focus-hover="1" href="javascript:void(0);" mt:command="remove" class="delete" title="[#|h trans("Remove") #]">&nbsp;<span>[#|h trans("Remove") #]</span></a></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

 }
}

sub transform_mt4_page {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;
    my $new_label2;

  if ($new_label = $plugin->get_data($blog_id, 'page_title')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Title">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-title" value="title" checked="checked" disabled="disabled" class="cb" /> <__trans phrase="Title"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-title" value="title" checked="checked" disabled="disabled" class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_status')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Status">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_entry_body')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Body"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-body" value="body" checked="checked" disabled="disabled" class="cb" /> <__trans phrase="Body"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-body" value="body" checked="checked" disabled="disabled" class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_extended_entry')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Extended"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_excerpt')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Excerpt">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-excerpt" value="excerpt" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_excerpt"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Excerpt"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-excerpt" value="excerpt" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_excerpt"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_keywords')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Keywords">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-keywords" value="keywords" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_keywords"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Keywords"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-keywords" value="keywords" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_keywords"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_tags')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Tags">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" onclick="setCustomFields(); return true;" name="custom_prefs" id="custom-prefs-tags" value="tags" <mt:if name="disp_prefs_show_tags"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Tags"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" onclick="setCustomFields(); return true;" name="custom_prefs" id="custom-prefs-tags" value="tags" <mt:if name="disp_prefs_show_tags"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_text_formatting')) {
    $old = quotemeta(<<'HTML');
                    <__trans phrase="Format:">
HTML
    $new = <<"HTML";
                    <__trans phrase="$new_label:">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_outbound_trackback_urls')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Outbound TrackBack URLs">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

 ### MT4.0 specific
 if (is_mt40()) {
  if ($new_label = $plugin->get_data($blog_id, 'page_publish_date')) {
    $old = quotemeta(<<'HTML');
    <mt:if name="status_future">
        <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">"$>
    <mt:else>
        <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">"$>
    </mt:if>
HTML
    $new = <<"HTML";
    <mt:if name="status_future">
        <\$mt:setvar name="authored_on_label" value="$new_label"\$>
    <mt:else>
        <\$mt:setvar name="authored_on_label" value="$new_label"\$>
    </mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_folder')) {
    $old = quotemeta(<<'HTML');
<mt:setvar name="container_label" value="<__trans phrase="Folder">">
HTML
    $new = <<"HTML";
<mt:setvar name="container_label" value="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_filename')) {
    $old = quotemeta(<<'HTML');
    <mt:setvar name="basename_label" value="<__trans phrase="Filename">">
HTML
    $new = <<"HTML";
    <mt:setvar name="basename_label" value="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Accept">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_comments')) {
    $old = quotemeta(<<'HTML');
            <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Comments"></li>
HTML
    $new = <<"HTML";
            <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> $new_label</li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_trackbacks')) {
    $old = quotemeta(<<'HTML');
            <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <__trans phrase="TrackBacks"></li>
HTML
    $new = <<"HTML";
            <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> $new_label</li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }
 }
 ### MT4.1 & MT4.2 specific
 if (is_mt41() || is_mt42()) {
  if ($new_label = $plugin->get_data($blog_id, 'page_publish_date')) {
    $old = quotemeta(<<'HTML');
        <mt:if name="status_future">
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">"$>
        <mt:else>
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">"$>
        </mt:if>
HTML
    $new = <<"HTML";
        <mt:if name="status_future">
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        <mt:else>
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        </mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_folder')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="container_label" value="<__trans phrase="Folder">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="container_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_filename')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="basename_label" value="<__trans phrase="Filename">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="basename_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept')) {
    $old = quotemeta(<<'HTML');
            label="<__trans phrase="Accept">"
HTML
    $new = <<"HTML";
            label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_comments')) {
    $old = quotemeta(<<'HTML');
                <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <label for="allow_comments"><__trans phrase="Comments"/></label></li>
HTML
    $new = <<"HTML";
                <li><input type="checkbox" name="allow_comments" id="allow_comments" tabindex="14" value="1"<mt:if name="allow_comments"> checked="checked"</mt:if> class="cb" /> <label for="allow_comments">$new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_trackbacks')) {
    $old = quotemeta(<<'HTML');
                <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <label for="allow_pings"><__trans phrase="TrackBacks"/></label></li>
HTML
    $new = <<"HTML";
                <li><input type="checkbox" name="allow_pings" id="allow_pings" tabindex="15" value="1"<mt:if name="allow_pings"> checked="checked"</mt:if> class="cb" /> <label for="allow_pings">$new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label2 = $plugin->get_data($blog_id, 'page_add_folder')) {
    $old = quotemeta(<<'HTML');
        <a href="javascript:void(0);" class="change-folder-link" mt:command="open-category-selector" title="<__trans phrase="Add folder">"><__trans phrase="Change Folder"/></a>
HTML
    $new = <<"HTML";
        <a href="javascript:void(0);" class="change-folder-link" mt:command="open-category-selector" title="$new_label2"><__trans phrase="Change Folder"/></a>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }
  else {
    $new_label2 = qq/<__trans phrase="Add folder">/;
  }
  if ($new_label = $plugin->get_data($blog_id, 'page_change_folder')) {
    $old = quotemeta(<<"HTML");
        <a href="javascript:void(0);" class="change-folder-link" mt:command="open-category-selector" title="$new_label2"><__trans phrase="Change Folder"/></a>
HTML
    $new = <<"HTML";
        <a href="javascript:void(0);" class="change-folder-link" mt:command="open-category-selector" title="$new_label2">$new_label</a>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }
 }
}

sub hdlr_edit_entry_mt4_source {
    my ($eh, $app, $tmpl_ref) = @_;
    my $q = $app->{'query'};

    if ($q->param('_type') eq 'entry') {
        transform_mt4_entry(@_);
    } elsif ($q->param('_type') eq 'page') {
        transform_mt4_page(@_);
    }
    1;
}

#----- MT5 -----

sub transform_mt5_entry {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'title')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Title">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'status')) {
    $old = quotemeta(<<'HTML');
    label="<__trans phrase="Status">">
HTML
    $new = <<"HTML";
    label="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'entry_body')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Body"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'extended_entry')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Extended"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'excerpt')) {
    $old = quotemeta(<<'HTML');
                label="$field_label"
                label_class="top-label"
                help_page="entries"
                help_section="excerpt">
HTML
    $new = <<"HTML";
                label="$new_label"
                label_class="top-label"
                help_page="entries"
                help_section="excerpt">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'keywords')) {
    $old = quotemeta(<<'HTML');
                label="$field_label"
                label_class="top-label"
                help_page="entries"
                help_section="keywords">
HTML
    $new = <<"HTML";
                label="$new_label"
                label_class="top-label"
                help_page="entries"
                help_section="keywords">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'tags')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Tags">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'text_formatting')) {
    $old = quotemeta(<<'HTML');
                    <__trans phrase="Format:">
HTML
    $new = <<"HTML";
                    <__trans phrase="$new_label:">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'outbound_trackback_urls')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Outbound TrackBack URLs">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publish_date')) {
    $old = quotemeta(<<'HTML');
<mt:if name="status_future">
    <mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">">
<mt:else>
    <mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">">
</mt:if>
HTML
    $new = <<"HTML";
<mt:if name="status_future">
    <\$mt:setvar name="authored_on_label" value="$new_label"\$>
<mt:else>
    <\$mt:setvar name="authored_on_label" value="$new_label"\$>
</mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'category')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Categories">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-category" value="category" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_category"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Categories"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-category" value="category" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_category"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'basename')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="basename_label" value="<__trans phrase="Basename">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="basename_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_comments')) {
    $old = quotemeta('<__trans phrase="Accept Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_trackbacks')) {
    $old = quotemeta('<__trans phrase="Accept Trackbacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'comments')) {
    $old = quotemeta(<<'HTML');
        id="entry-feedback-widget"
        label="<__trans phrase="Comments">">
HTML
    $new = <<"HTML";
        id="entry-feedback-widget"
        label="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;

    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-feedback" value="feedback" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_feedback"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Comments"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-feedback" value="feedback" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_feedback"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'trackbacks')) {
    $old = quotemeta(<<'HTML');
            id="allow_trackback"
            label="<__trans phrase="TrackBacks">"
HTML
    $new = <<"HTML";
            id="allow_trackback"
            label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publish_date')) {
    $old = quotemeta(<<'HTML');
        <mt:if name="status_future">
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">"$>
        <mt:else>
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">"$>
        </mt:if>
HTML
    $new = <<"HTML";
        <mt:if name="status_future">
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        <mt:else>
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        </mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category')) {
    $old = quotemeta(<<'HTML');
            <a href="javascript:void(0)" class="add-new-category-link" id="open-category-selector1" mt:command="open-category-selector" mt:close-el="close-category-selector1" title="<__trans phrase="Add category">"><__trans phrase="edit"/></a>
HTML
    $new = <<"HTML";
            <a href="javascript:void(0)" class="add-new-category-link" id="open-category-selector1" mt:command="open-category-selector" mt:close-el="close-category-selector1" title="$new_label"><__trans phrase="edit"/></a>
HTML
    $$tmpl_ref =~ s!$old!$new!;
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="add_container_label" value="<__trans phrase="Add category">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="add_container_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category_name')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="add_container_label_name" value="<__trans phrase="Add category name">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="add_container_label_name" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_new_category_parent')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="add_new_container_label_parent" value="<__trans phrase="Add new category parent">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="add_new_container_label_parent" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'make_primary')) {
    $old = quotemeta(<<'HTML');
                        <li mt:focus-hover="1" mt:id="[#= cat.id #]"><mt:if name="object_type" eq="entry"><a mt:focus-hover="1" href="javascript:void(0);" mt:command="primary" class="primary" title="[#|h trans("Make primary") #]">[#= label #]</a></mt:if><a mt:focus-hover="1" href="javascript:void(0);" mt:command="remove" class="delete" title="[#|h "Remove" #]">&nbsp;<span>[#|h trans("Remove") #]</span></a></li>
HTML
    $new = <<"HTML";
                        <li mt:focus-hover="1" mt:id="[#= cat.id #]"><mt:if name="object_type" eq="entry"><a mt:focus-hover="1" href="javascript:void(0);" mt:command="primary" class="primary" title="[#|h trans("$new_label") #]">[#= label #]</a></mt:if><a mt:focus-hover="1" href="javascript:void(0);" mt:command="remove" class="delete" title="[#|h "Remove" #]">&nbsp;<span>[#|h trans("Remove") #]</span></a></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publishing')) {
    $old = quotemeta(<<'HTML');
    id="entry-publishing-widget"
    label="<__trans phrase="Publishing">">
HTML
    $new = <<"HTML";
    id="entry-publishing-widget"
    label="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'change_note')) {
    $old = quotemeta('<__trans phrase="Change note">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

}

sub transform_mt5_page {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'page_title')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Title">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_status')) {
    $old = quotemeta(<<'HTML');
    label="<__trans phrase="Status">">
HTML
    $new = <<"HTML";
    label="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_entry_body')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Body"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_extended_entry')) {
    $old = quotemeta(<<'HTML');
                    <label><a href="javascript:void(0);"><__trans phrase="Extended"></a></label>
HTML
    $new = <<"HTML";
                    <label><a href="javascript:void(0);">$new_label</a></label>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_excerpt')) {
    $old = quotemeta(<<'HTML');
                label="$field_label"
                label_class="top-label"
                help_page="entries"
                help_section="excerpt">
HTML
    $new = <<"HTML";
                label="$new_label"
                label_class="top-label"
                help_page="entries"
                help_section="excerpt">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_keywords')) {
    $old = quotemeta(<<'HTML');
                label="$field_label"
                label_class="top-label"
                help_page="entries"
                help_section="keywords">
HTML
    $new = <<"HTML";
                label="$new_label"
                label_class="top-label"
                help_page="entries"
                help_section="keywords">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_tags')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Tags">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_text_formatting')) {
    $old = quotemeta(<<'HTML');
                    <__trans phrase="Format:">
HTML
    $new = <<"HTML";
                    <__trans phrase="$new_label:">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_outbound_trackback_urls')) {
    $old = quotemeta(<<'HTML');
        label="<__trans phrase="Outbound TrackBack URLs">"
HTML
    $new = <<"HTML";
        label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publish_date')) {
    $old = quotemeta(<<'HTML');
<mt:if name="status_future">
    <mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">">
<mt:else>
    <mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">">
</mt:if>
HTML
    $new = <<"HTML";
<mt:if name="status_future">
    <\$mt:setvar name="authored_on_label" value="$new_label"\$>
<mt:else>
    <\$mt:setvar name="authored_on_label" value="$new_label"\$>
</mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_folder')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="container_label" value="<__trans phrase="Folder">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="container_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_filename')) {
    $old = quotemeta(<<'HTML');
    <$mt:setvar name="basename_label" value="<__trans phrase="Filename">"$>
HTML
    $new = <<"HTML";
    <\$mt:setvar name="basename_label" value="$new_label"\$>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_comments')) {
    $old = quotemeta('<__trans phrase="Accept Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_trackbacks')) {
    $old = quotemeta('<__trans phrase="Accept Trackbacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_comments')) {
    $old = quotemeta(<<'HTML');
        id="entry-feedback-widget"
        label="<__trans phrase="Comments">">
HTML
    $new = <<"HTML";
        label="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;

    $old = quotemeta(<<'HTML');
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-feedback" value="feedback" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_feedback"> checked="checked"</mt:if> class="cb" /> <__trans phrase="Comments"></label></li>
HTML
    $new = <<"HTML";
                        <li><label><input type="checkbox" name="custom_prefs" id="custom-prefs-feedback" value="feedback" onclick="setCustomFields(); return true"<mt:if name="disp_prefs_show_feedback"> checked="checked"</mt:if> class="cb" /> $new_label</label></li>
HTML
    $$tmpl_ref =~ s!$old!$new!;

  }

  if ($new_label = $plugin->get_data($blog_id, 'page_trackbacks')) {
    $old = quotemeta(<<'HTML');
            id="allow_trackback"
            label="<__trans phrase="TrackBacks">"
HTML
    $new = <<"HTML";
            id="allow_trackback"
            label="$new_label"
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept')) {
    $old = quotemeta('<__trans phrase="Accept"/>');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publish_date')) {
    $old = quotemeta(<<'HTML');
        <mt:if name="status_future">
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish On">"$>
        <mt:else>
            <$mt:setvar name="authored_on_label" value="<__trans phrase="Publish Date">"$>
        </mt:if>
HTML
    $new = <<"HTML";
        <mt:if name="status_future">
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        <mt:else>
            <\$mt:setvar name="authored_on_label" value="$new_label"\$>
        </mt:if>
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }


  if ($new_label = $plugin->get_data($blog_id, 'page_add_folder')) {
    $old = quotemeta('<__trans phrase="Add folder">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_change_folder')) {
    $old = quotemeta('<__trans phrase="Change Folder"/>');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publishing')) {
    $old = quotemeta(<<'HTML');
    id="entry-publishing-widget"
    label="<__trans phrase="Publishing">">
HTML
    $new = <<"HTML";
    id="entry-publishing-widget"
    label="$new_label">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_change_note')) {
    $old = quotemeta('<__trans phrase="Change note">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }
}


sub hdlr_edit_entry_mt5_source {
    my ($eh, $app, $tmpl_ref) = @_;
    my $q = $app->{'query'};

    if ($q->param('_type') eq 'entry') {
        transform_mt5_entry(@_);
    } elsif ($q->param('_type') eq 'page') {
        transform_mt5_page(@_);
    }
    1;
}

sub hdlr_edit_entry_mt5_param {
    my ($cb, $app, $param, $tmpl) = @_;
    my $q = $app->{'query'};
    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my %dic = (
        'title' => 'title',
        'text' => 'entry_body',
        'tags' => 'tags',
        'excerpt' => 'excerpt',
        'keywords' => 'keywords',
    );
    my %rename_dic = ();
    for my $key ( keys %dic ) {
        my $new_label;
        if ($q->param('_type') eq 'entry') {
            if ($new_label = $plugin->get_data($blog_id, $dic{$key})) {
                $rename_dic{$key} = $new_label;
            }
        } elsif ($q->param('_type') eq 'page') {
            if ($new_label = $plugin->get_data($blog_id, 'page_' . $dic{$key})) {
                $rename_dic{$key} = $new_label;
            }
        }
    }
    my @fields;
    for my $field (@{$param->{field_loop}}) {
        my $name = $field->{field_name};
        if ($rename_dic{$name}) {
            $field->{field_label} = $rename_dic{$name};
        }
        push (@fields, $field);
    }

    $param->{field_loop} = \@fields;
}

#----- MT51 -----

sub transform_mt51_entry {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'title')) {
    $old = quotemeta('<__trans phrase="Title">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'status')) {
    $old = quotemeta('<__trans phrase="Status">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'entry_body')) {
    $old = quotemeta('<__trans phrase="Body">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'extended_entry')) {
    $old = quotemeta('<__trans phrase="Extended">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'excerpt')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'keywords')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'tags')) {
    $old = quotemeta('<__trans phrase="Tags">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'text_formatting')) {
    $old = quotemeta('<__trans phrase="Format:">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'outbound_trackback_urls')) {
    $old = quotemeta('<__trans phrase="Outbound TrackBack URLs">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publish_date')) {
    $old = quotemeta('<__trans phrase="Publish On">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
    $old = quotemeta('<__trans phrase="Publish Date">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'category')) {
    $old = quotemeta('<__trans phrase="Categories">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'basename')) {
    $old = quotemeta('<__trans phrase="Basename">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_comments')) {
    $old = quotemeta('<__trans phrase="Accept Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'accept_trackbacks')) {
    $old = quotemeta('<__trans phrase="Accept Trackbacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'comments')) {
    $old = quotemeta('<__trans phrase="Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'trackbacks')) {
    $old = quotemeta('<__trans phrase="TrackBacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category')) {
    $old = quotemeta('<__trans phrase="Add category">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_category_name')) {
    $old = quotemeta('<__trans phrase="Add category name">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'add_new_category_parent')) {
    $old = quotemeta('<__trans phrase="Add new category parent">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'make_primary')) {
    $old = quotemeta('[#|h trans("Make primary") #]');
    $new = '[#|h trans("' . $new_label . '") #]';
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'publishing')) {
    $old = quotemeta('<__trans phrase="Publishing">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'change_note')) {
    $old = quotemeta('<__trans phrase="Change note">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'entry_assets')) {
      $old = quotemeta('<__trans phrase="[_1] Assets" params="<mt:var name="object_label">">');
      $new = $new_label;
      $$tmpl_ref =~ s!$old!$new!g;
  }
}

sub transform_mt51_page {
    my ($eh, $app, $tmpl_ref) = @_;

    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my $old;
    my $new;
    my $new_label;

  if ($new_label = $plugin->get_data($blog_id, 'page_title')) {
    $old = quotemeta('<__trans phrase="Title">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_status')) {
    $old = quotemeta('<__trans phrase="Status">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_entry_body')) {
    $old = quotemeta('<__trans phrase="Body">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_extended_entry')) {
    $old = quotemeta('<__trans phrase="Extended">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_excerpt')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="excerpt">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_keywords')) {
    $old = quotemeta(<<'HTML');
       label="$field_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $new = <<"HTML";
       label="$new_label"
       label_class="top-label"
       help_page="entries"
       help_section="keywords">
HTML
    $$tmpl_ref =~ s!$old!$new!;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_tags')) {
    $old = quotemeta('<__trans phrase="Tags">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_text_formatting')) {
    $old = quotemeta('<__trans phrase="Format:">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_outbound_trackback_urls')) {
    $old = quotemeta('<__trans phrase="Outbound TrackBack URLs">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publish_date')) {
    $old = quotemeta('<__trans phrase="Publish On">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
    $old = quotemeta('<__trans phrase="Publish Date">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_folder')) {
    $old = quotemeta('<__trans phrase="Folder">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_filename')) {
    $old = quotemeta('<__trans phrase="Filename">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_comments')) {
    $old = quotemeta('<__trans phrase="Accept Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept_trackbacks')) {
    $old = quotemeta('<__trans phrase="Accept Trackbacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_comments')) {
    $old = quotemeta('<__trans phrase="Comments">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_trackbacks')) {
    $old = quotemeta('<__trans phrase="TrackBacks">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_accept')) {
    $old = quotemeta('<__trans phrase="Accept"/>');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_add_folder')) {
    $old = quotemeta('<__trans phrase="Add folder">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_change_folder')) {
    $old = quotemeta('<__trans phrase="Change Folder"/>');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_publishing')) {
    $old = quotemeta('<__trans phrase="Publishing">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_change_note')) {
    $old = quotemeta('<__trans phrase="Change note">');
    $new = $new_label;
    $$tmpl_ref =~ s!$old!$new!g;
  }

  if ($new_label = $plugin->get_data($blog_id, 'page_assets')) {
      $old = quotemeta('<__trans phrase="[_1] Assets" params="<mt:var name="object_label">">');
      $new = $new_label;
      $$tmpl_ref =~ s!$old!$new!g;
  }
}


sub hdlr_edit_entry_mt51_source {
    my ($eh, $app, $tmpl_ref) = @_;
    my $q = $app->{'query'};

    if ($q->param('_type') eq 'entry') {
        transform_mt51_entry(@_);
    } elsif ($q->param('_type') eq 'page') {
        transform_mt51_page(@_);
    }
    1;
}

sub hdlr_edit_entry_mt51_param {
    my ($cb, $app, $param, $tmpl) = @_;
    my $q = $app->{'query'};
    my $blog = $app->blog;
    my $blog_id = $blog->id;

    my %dic = (
        'title' => 'title',
        'text' => 'entry_body',
        'tags' => 'tags',
        'excerpt' => 'excerpt',
        'keywords' => 'keywords',
    );
    my %rename_dic = ();
    for my $key ( keys %dic ) {
        my $new_label;
        if ($q->param('_type') eq 'entry') {
            if ($new_label = $plugin->get_data($blog_id, $dic{$key})) {
                $rename_dic{$key} = $new_label;
            }
        } elsif ($q->param('_type') eq 'page') {
            if ($new_label = $plugin->get_data($blog_id, 'page_' . $dic{$key})) {
                $rename_dic{$key} = $new_label;
            }
        }
    }
    my @fields;
    for my $field (@{$param->{field_loop}}) {
        my $name = $field->{field_name};
        if ($rename_dic{$name}) {
            $field->{field_label} = $rename_dic{$name};
        }
        push (@fields, $field);
    }

    $param->{field_loop} = \@fields;
}

# For MT6
sub hdlr_edit_entry_mt6_source {
    my ($eh, $app, $tmpl_ref) = @_;

    hdlr_edit_entry_mt51_source(@_);

    my $blog_id = $app->blog->id;
    if (my $new_label = $plugin->get_data($blog_id, 'unpublish_date')) {
        my $old_label = quotemeta('<__trans phrase="Unpublish Date">');
        $$tmpl_ref =~ s!$old_label!$new_label!g;
    }

    return 1;
}

sub hdlr_edit_entry_mt6_param {
    my ($cb, $app, $param, $tmpl) = @_;
    hdlr_edit_entry_mt51_param(@_);
}

1;

